@@ -1,5 +1,5 @@
 package Acme::CPANAuthors::POE;
-$Acme::CPANAuthors::POE::VERSION = '0.74';
+$Acme::CPANAuthors::POE::VERSION = '0.76';
 #ABSTRACT: We are CPAN Authors of POE
 
 use strict;
@@ -13,33 +13,43 @@ use Acme::CPANAuthors::Register (
   AGRUNDMA => q[Andy Grundman],
   AHOYING => q[Andrew Hoying],
   AIMASS => q[Alejandro Imass],
+  AJCT => q[Adam Taylor],
   ANDYPUR => q[Andrew V. Purshottam],
   APOCAL => q[Apocalypse],
   ARCANEZ => q[Justin Hunter],
   AVENJ => q[Jon Portnoy],
   BEVO => q[Brendan Beveridge],
+  BIGPRESH => q[David Precious],
   BINGOS => q[Chris Williams],
   BLHOTSKY => q[Brad Lhotsky],
+  BOOK => q[Philippe Bruhat (BooK)],
   BSMITH => q[Benjamin Smith],
   BTROTT => q[Benjamin Trott],
   CATONE => q[Denis Pokataev],
   CCOBB => q[Chris Cobb],
   CFEDDE => q[Chris Fedde],
+  CLAESJAC => q[Claes Jakobsson],
+  COSIMO => q[Cosimo Streppone],
   CURTIS => q[Curtis Brandt],
   CWEST => q[Casey West],
   DAGOLDEN => q[David Golden],
   DAMS => q[Damien Krotkine],
   DAVINCHI => q[Pavel Boldin],
   DAZJORZ => q[Sjors Gielen],
+  DIZ => q[Mike Eldridge],
   DMAKI => q[Daisuke Maki],
   DMCC => q[Dan McCormick],
   DOLMEN => q[Olivier Mengue],
   DOUGDUDE => q[Douglas Christopher Wilson],
   DSNOPEK => q[David Snopek],
+  DUTCHIE => q[Josh Holland],
   ECALDER => q[Erick Calder],
+  EDOARDO => q[Edoardo Sabadelli],
   ERIAM => q[Eriam Schaffter],
+  ESTRAI => q[Daniel (Estrai) Lukasiak],
   EWATERS => q[Eric Waters],
   FLETCH => q[Mike Fletcher],
+  FRANCKC => q[Franck Cuny],
   FRODWITH => q[Paul Driver],
   GDSL => q[Sergey Skvortsov],
   GETTY => q[Torsten Raudssus],
@@ -53,22 +63,30 @@ use Acme::CPANAuthors::Register (
   HDP => q[Hans Dieter Pearcey],
   HEYTRAV => q[William Travis Holton],
   HINRIK => q[Hinrik Orn Sigurdsson],
+  IDERRICK => q[Olivier Schwander],
   INFIDEL => q[Jason McManus],
   IRONCAMEL => q[Naveed Massjouni],
+  IVORW => q[Ivor Williams],
   JBISBEE => q[Jeff Bisbee],
   JGOFF => q[Jeff Goff],
+  JHELWIG => q[Jacob Helwig],
+  JKG => q[James Green],
   JMERELO => q[J. J. Merelo Guervos],
   JQUELIN => q[Jerome Quelin],
+  JROBINSON => q[Jess Robinson],
   JSN => q[dmitry kim],
+  KAKE => q[Kake],
   KARASIK => q[Dmitry Karasik],
   KESTEB => q[Kevin L. Esteb],
   KIRILLM => q[Kirill Miazine],
+  KITANO => q[dann],
   KIXX => q[Christian-Rolf Gruen],
   LOSYME => q[Loic TROCHET],
   MAHEX => q[Mark A. Hershberger],
   MARTIJN => q[Martijn van Beers],
   MCHING => q[Michael Ching],
   MCMIC => q[Come BERNIGAUD],
+  MDOM => q[Mario Domgoergen],
   MELO => q[Pedro Melo],
   MGV => q[Marius Gavrilescu],
   MIKE => q[Mike Schroeder],
@@ -82,12 +100,14 @@ use Acme::CPANAuthors::Register (
   MOCK => q[MOCK],
   MOCONNOR => q[Matthew O'Connor],
   MRDVT => q[Michael R. Davis],
+  MRF => q[Mike Francis],
   MRPERSON => q[Curtis Hawthorne],
   MSCHILLI => q[Michael Schilli],
   MSERGEANT => q[MSERGEANT],
   MSTROUT => q[Matt S Trout],
   NPEREZ => q[Nicholas Perez],
   NUFFIN => q[Yuval Kogman],
+  OMNI => q[Michael Alexander],
   PAULV => q[Paul Visscher],
   PEVANS => q[Paul Evans],
   PGUZIS => q[Peter Guzis],
@@ -99,6 +119,7 @@ use Acme::CPANAuthors::Register (
   RCLAMP => q[Richard Clamp],
   RDB => q[Rob Bloodgood],
   RDRAKE => q[Robert Drake],
+  RECSKY => q[Frederico Recsky],
   REVMISCHA => q[Mischa Spiegelmock],
   RJBS => q[Ricardo SIGNES],
   RJP => q[Rob Partington],
@@ -108,6 +129,7 @@ use Acme::CPANAuthors::Register (
   SCILLEY => q[Scott Cilley],
   SEGAN => q[Sean Egan],
   SHARIFULN => q[Anatoly Sharifulin],
+  SIMONW => q[Simon Wistow],
   SIRMXE => q[Gary Warman],
   SMCNABB => q[Steve McNabb],
   SPADKINS => q[Stephen Adkins],
@@ -124,7 +146,9 @@ use Acme::CPANAuthors::Register (
   ULTRADM => q[George Patrascan],
   VANY => q[Ivan B. Serezhkin],
   WANG => q[wb@95700.net],
+  WAZZUTEKE => q[Trevor Hall],
   WHOPPIX => q[Jonathan Ringstad],
+  WWOLF => q[William Wolf],
   XANTUS => q[David Davis],
   XSAWYERX => q[Sawyer X],
   YAPPO => q[Kazuhiro Osawa],
@@ -146,7 +170,7 @@ Acme::CPANAuthors::POE - We are CPAN Authors of POE
 
 =head1 VERSION
 
-version 0.74
+version 0.76
 
 =head1 SYNOPSIS
 
@@ -176,33 +200,43 @@ It is currently statically generated information, I hope to make it dynamic in t
   AGRUNDMA => q[Andy Grundman],
   AHOYING => q[Andrew Hoying],
   AIMASS => q[Alejandro Imass],
+  AJCT => q[Adam Taylor],
   ANDYPUR => q[Andrew V. Purshottam],
   APOCAL => q[Apocalypse],
   ARCANEZ => q[Justin Hunter],
   AVENJ => q[Jon Portnoy],
   BEVO => q[Brendan Beveridge],
+  BIGPRESH => q[David Precious],
   BINGOS => q[Chris Williams],
   BLHOTSKY => q[Brad Lhotsky],
+  BOOK => q[Philippe Bruhat (BooK)],
   BSMITH => q[Benjamin Smith],
   BTROTT => q[Benjamin Trott],
   CATONE => q[Denis Pokataev],
   CCOBB => q[Chris Cobb],
   CFEDDE => q[Chris Fedde],
+  CLAESJAC => q[Claes Jakobsson],
+  COSIMO => q[Cosimo Streppone],
   CURTIS => q[Curtis Brandt],
   CWEST => q[Casey West],
   DAGOLDEN => q[David Golden],
   DAMS => q[Damien Krotkine],
   DAVINCHI => q[Pavel Boldin],
   DAZJORZ => q[Sjors Gielen],
+  DIZ => q[Mike Eldridge],
   DMAKI => q[Daisuke Maki],
   DMCC => q[Dan McCormick],
   DOLMEN => q[Olivier Mengue],
   DOUGDUDE => q[Douglas Christopher Wilson],
   DSNOPEK => q[David Snopek],
+  DUTCHIE => q[Josh Holland],
   ECALDER => q[Erick Calder],
+  EDOARDO => q[Edoardo Sabadelli],
   ERIAM => q[Eriam Schaffter],
+  ESTRAI => q[Daniel (Estrai) Lukasiak],
   EWATERS => q[Eric Waters],
   FLETCH => q[Mike Fletcher],
+  FRANCKC => q[Franck Cuny],
   FRODWITH => q[Paul Driver],
   GDSL => q[Sergey Skvortsov],
   GETTY => q[Torsten Raudssus],
@@ -216,22 +250,30 @@ It is currently statically generated information, I hope to make it dynamic in t
   HDP => q[Hans Dieter Pearcey],
   HEYTRAV => q[William Travis Holton],
   HINRIK => q[Hinrik Orn Sigurdsson],
+  IDERRICK => q[Olivier Schwander],
   INFIDEL => q[Jason McManus],
   IRONCAMEL => q[Naveed Massjouni],
+  IVORW => q[Ivor Williams],
   JBISBEE => q[Jeff Bisbee],
   JGOFF => q[Jeff Goff],
+  JHELWIG => q[Jacob Helwig],
+  JKG => q[James Green],
   JMERELO => q[J. J. Merelo Guervos],
   JQUELIN => q[Jerome Quelin],
+  JROBINSON => q[Jess Robinson],
   JSN => q[dmitry kim],
+  KAKE => q[Kake],
   KARASIK => q[Dmitry Karasik],
   KESTEB => q[Kevin L. Esteb],
   KIRILLM => q[Kirill Miazine],
+  KITANO => q[dann],
   KIXX => q[Christian-Rolf Gruen],
   LOSYME => q[Loic TROCHET],
   MAHEX => q[Mark A. Hershberger],
   MARTIJN => q[Martijn van Beers],
   MCHING => q[Michael Ching],
   MCMIC => q[Come BERNIGAUD],
+  MDOM => q[Mario Domgoergen],
   MELO => q[Pedro Melo],
   MGV => q[Marius Gavrilescu],
   MIKE => q[Mike Schroeder],
@@ -245,12 +287,14 @@ It is currently statically generated information, I hope to make it dynamic in t
   MOCK => q[MOCK],
   MOCONNOR => q[Matthew O'Connor],
   MRDVT => q[Michael R. Davis],
+  MRF => q[Mike Francis],
   MRPERSON => q[Curtis Hawthorne],
   MSCHILLI => q[Michael Schilli],
   MSERGEANT => q[MSERGEANT],
   MSTROUT => q[Matt S Trout],
   NPEREZ => q[Nicholas Perez],
   NUFFIN => q[Yuval Kogman],
+  OMNI => q[Michael Alexander],
   PAULV => q[Paul Visscher],
   PEVANS => q[Paul Evans],
   PGUZIS => q[Peter Guzis],
@@ -262,6 +306,7 @@ It is currently statically generated information, I hope to make it dynamic in t
   RCLAMP => q[Richard Clamp],
   RDB => q[Rob Bloodgood],
   RDRAKE => q[Robert Drake],
+  RECSKY => q[Frederico Recsky],
   REVMISCHA => q[Mischa Spiegelmock],
   RJBS => q[Ricardo SIGNES],
   RJP => q[Rob Partington],
@@ -271,6 +316,7 @@ It is currently statically generated information, I hope to make it dynamic in t
   SCILLEY => q[Scott Cilley],
   SEGAN => q[Sean Egan],
   SHARIFULN => q[Anatoly Sharifulin],
+  SIMONW => q[Simon Wistow],
   SIRMXE => q[Gary Warman],
   SMCNABB => q[Steve McNabb],
   SPADKINS => q[Stephen Adkins],
@@ -287,7 +333,9 @@ It is currently statically generated information, I hope to make it dynamic in t
   ULTRADM => q[George Patrascan],
   VANY => q[Ivan B. Serezhkin],
   WANG => q[wb@95700.net],
+  WAZZUTEKE => q[Trevor Hall],
   WHOPPIX => q[Jonathan Ringstad],
+  WWOLF => q[William Wolf],
   XANTUS => q[David Davis],
   XSAWYERX => q[Sawyer X],
   YAPPO => q[Kazuhiro Osawa],
